CWI-2 - Wikipedia

# CWI-2

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

CWI-2[1] (a.k.a. CWI, cp-hu,[1][2] HUCWI, or HU8CWI2[3]) is a Hungarian code page frequently used in the 1980s and early 1990s. If this code page is erroneously interpreted as code page 437, it will still be fairly readable (e.g. Á in place of Å).

## Character set[edit]

The following table shows "CWI-2". Each character is shown with its equivalent Unicode code point. Only the second half is shown, codes less than 128 are identical to code page 437.

CWI-2
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
8_ 128 | Ç 00C7 | ü 00FC | é 00E9 | â 00E2 | ä 00E4 | à 00E0 | å 00E5 | ç 00E7 | ê 00EA | ë 00EB | è 00E8 | ï 00EF | î 00EE | Í 00CD | Ä 00C4 | Á 00C1
9_ 144 | É 00C9 | æ 00E6 | Æ 00C6 | ő 0151 | ö 00F6 | Ó 00D3 | ű 0171 | Ú 00DA | Ű 0170 | Ö 00D6 | Ü 00DC | ¢ 00A2 | £ 00A3 | ¥ 00A5 | ₧ 20A7 | ƒ 0192
A_ 160 | á 00E1 | í 00ED | ó 00F3 | ú 00FA | ñ 00F1 | Ñ 00D1 | ª 00AA | Ő 0150 | ¿ 00BF | ⌐ 2310 | ¬ 00AC | ½ 00BD | ¼ 00BC | ¡ 00A1 | « 00AB | » 00BB
B_ 176 | ░ 2591 | ▒ 2592 | ▓ 2593 | │ 2502 | ┤ 2524 | ╡ 2561 | ╢ 2562 | ╖ 2556 | ╕ 2555 | ╣ 2563 | ║ 2551 | ╗ 2557 | ╝ 255D | ╜ 255C | ╛ 255B | ┐ 2510
C_ 192 | └ 2514 | ┴ 2534 | ┬ 252C | ├ 251C | ─ 2500 | ┼ 253C | ╞ 255E | ╟ 255F | ╚ 255A | ╔ 2554 | ╩ 2569 | ╦ 2566 | ╠ 2560 | ═ 2550 | ╬ 256C | ╧ 2567
D_ 208 | ╨ 2568 | ╤ 2564 | ╥ 2565 | ╙ 2559 | ╘ 2558 | ╒ 2552 | ╓ 2553 | ╫ 256B | ╪ 256A | ┘ 2518 | ┌ 250C | █ 2588 | ▄ 2584 | ▌ 258C | ▐ 2590 | ▀ 2580
E_ 224 | α 03B1 | ß 00DF | Γ 0393 | π 03C0 | Σ 03A3 | σ 03C3 | µ 00B5 | τ 03C4 | Φ 03A6 | Θ 0398 | Ω 03A9 | δ 03B4 | ∞ 221E | φ 03C6 | ε 03B5 | ∩ 2229
F_ 240 | ≡ 2261 | ± 00B1 | ≥ 2265 | ≤ 2264 | ⌠ 2320 | ⌡ 2321 | ÷ 00F7 | ≈ 2248 | ° 00B0 | ∙ 2219 | · 00B7 | √ 221A | ⁿ 207F | ² 00B2 | ■ 25A0 | NBSP 00A0

Letter Number Punctuation Symbol Other Undefined Differences from code page 437

The Unicode encoding used by recode appears to differ in a number of code points:[2]

    9F | U+E01F | HUNGARIAN FLORIN (CWI_9F)
    E1 | U+03B2 | GREEK SMALL LETTER BETA
    E6 | U+03BC | GREEK SMALL LETTER MU
    ED | U+2205 | EMPTY SET
    F8 | U+2218 | RING OPERATOR
    F9 | U+00B7 | MIDDLE DOT
    FA | U+2022 | BULLET

Several applications developed in Hungary use almost identical character sets with slight modifications, which include § (U+00A7, SECTION SIGN) at 0x9D and a forint sign (an upper-case F and lower-case t ligated into a single character) at 0x9E or 0xA8. The florin sign was planned to be disunified, but so many encodings have this, it would disrupt many mappings.[4] The forint is usually abbreviated as "Ft"; most Hungarians recognize a lower-case "f" (whether upright or cursive) as meaning fillér, the now-unused subdivision of the forint. Some dot matrix printers of the NEC Pinwriter series, namely the P3200/P3300 (P20/P30), P6200/P6300 (P60/P70), P9300 (P90), P7200/P7300 (P62/P72), P22Q/P32Q, P3800/P3900 (P42Q/P52Q), P1200/P1300 (P2Q/P3Q), P2000 (P2X) and P8000 (P72X), supported the installation of optional font EPROMs.[5] Named "CWI" the optional ROM #7 "Hungaria" included this encoding, invokable via escape sequence `ESC R (n)` with (n) = 21.[5]

### CWI-1[edit]

The codepage CWI-1 differs only by the position of „Í” (U+00CD, LATIN CAPITAL LETTER I WITH ACUTE) on position 8C instead of 8D and „Ő” (U+0150, LATIN CAPITAL LETTER O WITH DOUBLE ACUTE) on position 8B instead of A7.[6] This codepage is known by Star printers and FreeDOS as Code page 3845.

## See also[edit]

- Kamenický encoding
- Mazovia encoding

## References[edit]

1. ^ a b
   "CWI-2". Computerworld Számítástechnika. 1.0. 3 (13). 1988-06-29.
2. ^ a b Flohr, Guido (2009) [2002]. "Locale::RecodeData::CWI - Conversion routines for CWI". CPAN libintl-perl. 1.0. Archived from the original on 2016-06-06. Retrieved 2016-06-06.
3. ^ Baird, Cathy; Chiba, Dan; Chu, Winson; Fan, Jessica; Ho, Claire; Law, Simon; Lee, Geoff; Linsley, Peter; Matsuda, Keni; Oscroft, Tamzin; Takeda, Shige; Tanaka, Linus; Tozawa, Makoto; Trute, Barry; Tsujimoto, Mayumi; Wu, Ying; Yau, Michael; Yu, Tim; Wang, Chao; Wong, Simon; Zhang, Weiran; Zheng, Lei; Zhu, Yan; Moore, Valarie (2002) [1996]. "Appendix A: Locale Data" (PDF). Oracle9i Database Globalization Support Guide (Release 2 (9.2) ed.). Oracle Corporation. Oracle A96529-01. Archived (PDF) from the original on 2017-02-14. Retrieved 2017-02-14.
4. ^ "Proposal to encode a Florin currency symbol" (PDF).
5. ^ a b Pinwriter Familie - Pinwriter - Epromsockel - Zusätzliche Zeichensätze / Schriftarten (Printed reference manual for optional font and code page EPROMs for NEC Pinwriters, including custom variants) (in German) (00 3/93 ed.), NEC Deutschland GmbH, 1993
6. ^ Láng, Attila D. (2001-10-15). Drótos, László (ed.). "Íráskalauz" [Guide to Writing] (in Hungarian). Hungarian Electronic Library. Retrieved 2017-10-20.

Retrieved from "https://en.wikipedia.org/w/index.php?title=CWI-2&oldid=1000490261"
Categories:

- Character encoding

Hidden categories:

- CS1 German-language sources (de)
- CS1 Hungarian-language sources (hu)